@@ -1,5 +1,5 @@
-import asyncio
 import click
+import modules.exceptions as ex
 
 from modules.host.sessions import new_session
 from modules.host.protocol import HostProtocol, MessageTypes
@@ -35,7 +35,7 @@ async def main(host_tag):
 @click.command()
 @click.argument('host_tag')
 def cli(host_tag):
-    asyncio.get_event_loop().run_until_complete(main(host_tag))
+    ex.run_and_catch(main(host_tag))
 
 
 if __name__ == '__main__':
